@@ -71,6 +71,7 @@ class PackageManager(QObject):
         self._to_remove_package_set = set()  # type: Set[str] # A set of packages that need to be removed at the next start
         self._to_install_package_dict = {}  # type: Dict[str, Dict[str, Any]]  # A dict of packages that need to be installed at the next start
         self._dismissed_packages = set()    # type: Set[str] # A set of packages that are dismissed by the user
+        self._installed_packages = {}  # type: Dict[str, Dict[str, Any]]  # A dict of packages that were installed during startup
 
         # There can be plugins that provide remote packages (and thus, newer / different versions for a package).
         self._available_package_versions = {}  # type: Dict[str, Set[UMVersion]]
@@ -167,7 +168,7 @@ class PackageManager(QObject):
                 with open(search_path, "r", encoding = "utf-8") as f:
                     self._bundled_package_dict.update(json.load(f))
                     Logger.log("i", "Loaded bundled packages data from %s", search_path)
-            except UnicodeDecodeError:
+            except (UnicodeDecodeError, JSONDecodeError):
                 Logger.logException("e", "Can't decode package management files. File is corrupt.")
                 return
             except FileNotFoundError:
@@ -284,7 +285,8 @@ class PackageManager(QObject):
             message = Message(catalog.i18nc("@error:uninstall",
                                             "There were some errors uninstalling the following packages:\n{packages}".format(
                                             packages = "- " + "\n- ".join(remove_failures))),
-                              title = catalog.i18nc("@info:title", "Uninstalling errors"))
+                              title = catalog.i18nc("@info:title", "Uninstalling errors"),
+                              message_type = Message.MessageType.ERROR)
             message.show()
 
         self._to_remove_package_set = remove_failures
@@ -297,6 +299,7 @@ class PackageManager(QObject):
             installing_plugin_msg = catalog.i18nc("@info:progress Don't translate {package_id}", "Installing plugin {package_id}...").format(package_id = package_id)
             self._application.showSplashMessage(installing_plugin_msg)
             self._installPackage(package_info)
+            self._installed_packages[package_id] = self._installed_package_dict[package_id]
             del self._to_install_package_dict[package_id]
             self._saveManagementData()
 
@@ -584,7 +587,8 @@ class PackageManager(QObject):
                                             "There was an error uninstalling the package {package} before installing "
                                             "new version:\n{error}.\nPlease try to upgrade again later.".format(
                                             package = package_id, error = str(e))),
-                              title = catalog.i18nc("@info:title", "Updating error"))
+                              title = catalog.i18nc("@info:title", "Updating error"),
+                              message_type = Message.MessageType.ERROR)
             message.show()
             return
 
@@ -725,5 +729,8 @@ class PackageManager(QObject):
         else:
             return ""
 
+    def getPackagesInstalledOnStartup(self) -> Dict[str, Dict[str, Any]]:
+        return self._installed_packages
+
 
 __all__ = ["PackageManager"]
