@@ -1,7 +1,7 @@
 # Copyright (c) 2015 Ultimaker B.V.
 # Uranium is released under the terms of the LGPLv3 or higher.
 
-from PyQt5.QtCore import QObject, pyqtSignal, pyqtProperty
+from PyQt5.QtCore import QObject, pyqtSignal, pyqtProperty, Q_ENUMS
 
 from UM.i18n import i18nCatalog
 from UM.Application import Application
@@ -11,6 +11,9 @@ i18n_catalog = i18nCatalog("uranium")
 
 
 class BackendProxy(QObject):
+
+    Q_ENUMS(BackendState) # Expose the BackendState enum to QML
+
     def __init__(self, parent = None):
         super().__init__(parent)
         self._backend = Application.getInstance().getBackend()
@@ -28,17 +31,21 @@ class BackendProxy(QObject):
 
     backendStateChange = pyqtSignal(int, arguments = ["state"])
 
-    ##  Returns the current state of processing of the backend.
-    #
-    #   \return \type{IntEnum} The current state of the backend.
     @pyqtProperty(int, notify = backendStateChange)
     def state(self):
+        """Returns the current state of processing of the backend.
+
+        :return: :type{IntEnum} The current state of the backend.
+        """
+
         return self._state
 
     def _onProcessingProgress(self, amount):
-        self._progress = amount
-        self.processingProgress.emit(amount)
+        if self._progress != amount:
+            self._progress = amount
+            self.processingProgress.emit(amount)
 
     def _onBackendStateChange(self, state):
-        self._state = state
-        self.backendStateChange.emit(state)
+        if self._state != state:
+            self._state = state
+            self.backendStateChange.emit(state)
