@@ -7,8 +7,10 @@ from PyQt5.QtGui import QKeyEvent
 from UM.InputDevice import InputDevice
 from UM.Event import KeyEvent
 
-##    In between class that converts QT key events to Uranium events.
+
 class QtKeyDevice(InputDevice):
+    """In between class that converts QT key events to Uranium events."""
+
     def __init__(self):
         super().__init__()
 
