@@ -4,8 +4,6 @@
 #Shoopdawoop
 from . import FileLogger
 
-from UM.i18n import i18nCatalog
-i18n_catalog = i18nCatalog("uranium")
 
 def getMetaData():
     return {
