@@ -1,5 +1,5 @@
 # Copyright (c) 2015 Ultimaker B.V.
-# Uranium is released under the terms of the AGPLv3 or higher.
+# Uranium is released under the terms of the LGPLv3 or higher.
 
 from . import RotateTool
 
@@ -11,7 +11,7 @@ def getMetaData():
         "tool": {
             "name": i18n_catalog.i18nc("@label", "Rotate"),
             "description": i18n_catalog.i18nc("@info:tooltip", "Rotate Model"),
-            "icon": "rotate",
+            "icon": "Rotate",
             "tool_panel": "RotateTool.qml",
             "weight": 1
         }
